#
# This example opens all optical channels to generate a PRBS signal.
#
import grpc
import queue
import os
import numpy as np

from spidr4 import tpx4tools, rpc
import example_config as e

# Select PRBS mdoe
PRBS_MODE=0x4

# Select bits for which channels should generate a signal
CHANNELS_TOP=0xff
CHANNELS_BOT=0xff

with grpc.insecure_channel(e.spidr4host()) as channel:
    # Get the services
    # ------------------------------------------------------------------------------------------------------
    control = rpc.ControlInfoStub(channel)
    tpx4 = rpc.Timepix4Stub(channel)
    datastream = rpc.DataStreamStub(channel)

    # Reset the pixel chips (will also load the default configuration)
    # ------------------------------------------------------------------------------------------------------
    control.ResetPixelChips(rpc.EMPTY)

    # Configure the output
    # ------------------------------------------------------------------------------------------------------
    datastream.ConfigOptical(rpc.OpticalLinkConfig(
        idx=e.spidr4chip(),
        channels= ( CHANNELS_BOT << 8 ) | CHANNELS_TOP,            # Enable all 16 channels (may also be 0, which means 'all available')
        link_speed=333          # 2.56 GHz
    ))

    # Configure PRBS (no high-level support though)
    tpx4tools.enable_prbs(tpx4, CHANNELS_TOP, CHANNELS_BOT, PRBS_MODE)
